# Reference
<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

**Classes**

* [`resolv_conf`](#resolv_conf): Manage the DNS resolver configuration file /etc/resolv.conf

## Classes

### resolv_conf

Manage the DNS resolver configuration file /etc/resolv.conf

#### Examples

##### Create resolver config file using default parameters

```puppet

class { resolv_conf': }
```

##### Create resolver config file with specific nameservers

```puppet

class { resolv_conf':
  nameservers              => [ '8.8.8.8', '8.8.4.4', ],
}
```

##### Create resolver config file with specific nameservers & options

```puppet

class { resolv_conf':
  nameservers              => [ '8.8.8.8', '8.8.4.4', ],
  options                  => [ 'rotate', 'timeout:2, ],
}
```

##### Create resolver config file where a local nameserver is prefered

```puppet

class { resolv_conf':
  nameservers              => [ '8.8.8.8', '8.8.4.4', ],
  prepend_local_nameserver => true,
}
```

#### Parameters

The following parameters are available in the `resolv_conf` class.

##### `nameservers`

Data type: `Array[String,0,3]`

An array of nameservers that the resolver should query for hostname
lookups. A maximum number of three nameservers can be specified. The
default value is a single element array containing `127.0.0.1`.

##### `domainname`

Data type: `Optional[String]`

A string that is the primary domain of the host. Unqualified lookups will
append this string to the query host. This parameter cannot be used
together with `searchlist`.

Default value: `undef`

##### `searchlist`

Data type: `Array[String,0,6]`

An array of domains that the resolver will search. A maximum of 6 domains
can be specified. This parameter cannot be used together with
`domainname`.

Default value: []

##### `sortlist`

Data type: `Array[String,0,10]`

An array of up to 10 IP/netmask items. These are used by the resolver to
sort the result in case multiple addresses are returned.

Default value: []

##### `options`

Data type: `Array[String]`

An array of option settings for the resolver. Each array element must be
the option to include in the configuration. The following options are
recognized: `ndots:n`, `timeout:n`, `attempts:n`, `debug`, `edns0`,
`inet6`, `ip6-bytestring`, `ip6-dotint`, `no-ip6-dotint`,
`no-check-names`, `rotate`, `single-request`, `single-request-reopen`.
The first three options are expected to use a numeric value for `n` after
the colon. Check the man page `resolv.conf(5)` for details.

Default value: []

##### `prepend_local_nameserver`

Data type: `Boolean`

A boolean value that determines if a local DNS server should be used
first. Setting this parameter to `true` will add `127.0.0.1` before the
servers given as `nameservers`. The last nameserver is silently ignored
if this would create a configuration with more than three servers. The
default value is `false`.

Default value: `false`

##### `resolv_conf_file`

Data type: `Stdlib::Absolutepath`

The absolute path of the file to manage. The default is
`/etc/resolv.conf`. In general it does not make sense to change this
parameter.

##### `owner`

Data type: `Optional[String]`

The owner of the file `/etc/resolv.conf`. The default is `root`.

Default value: `undef`

##### `group`

Data type: `Optional[String]`

The group of the file `/etc/resolv.conf`. The default is `root` on Linux
and `wheel` on FreeBSD.

Default value: `undef`

##### `mode`

Data type: `Optional[Stdlib::Filemode]`

The file mode of the file `/etc/resolv.conf`. The default is `0644`.

Default value: `undef`

